/* Copyright (C) 2010-2011 Red Hat, Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

#include <config.h>

#include <error.h>
#include <stdlib.h>
#include <string.h>

#include "iwh.h"	/* _() */
#include "user.h"
#include "xalloc.h"

static const char		*username, *userpass;

struct user *
user_lookup (const char *userid)
{
	/*
	 * We do not have a real user table yet, so just compare with -U.
	 */
	if (username == NULL || strcmp(userid, username) != 0)
		return NULL;

	struct user *ret = malloc(sizeof *ret);
	if (!ret)
		return NULL;
	memset(ret,0,sizeof *ret);
	strcpy(ret->name, username);
	strcpy(ret->pass, userpass);
	return ret;
}

void
user_add(const char *usercred)
{
	const char *p = strchr(usercred,':');
	if (!p) {
		error (EXIT_FAILURE, 0,
		       _("The -U argument must contain a colon"));
	}
	if (p == usercred) {
		error (EXIT_FAILURE, 0,
		       _("The user part of -U argument is empty"));
	}
	username = xstrndup(usercred,p-usercred);
	userpass = xstrdup(p+1);
	if (strlen(username) > USERNAME_MAX) {
		error (EXIT_FAILURE, 0, _("User name too long"));
	}
	if (strlen(userpass) > USERPASS_MAX) {
		error (EXIT_FAILURE, 0, _("User password too long"));
	}
}
